# WEATHER CLI APP

This weather CLI app was built using standard Python modules and
OpenWeatherMap API to retrieve weather conditions of cities
around the world.

It takes in city as an argument and the temperature can be defined
at the start of the program.

## INSTALLATION

The weather app can be installed via Pip
```sh
pip install weather-app-cli
```

## USAGE

To run this app, ensure Python 3.5+ is available on your system.

```sh
python3 -m weather {city} {-i}
```
where {city} is the name of the city you would like to check
and {-i} is used to set temperature to Celsius or Fahrenheit.

# __REFERENCE__
This app was constructed in relation to a [tutorial](https://realpython.com/build-a-python-weather-app-cli) on RealPython.
Few modifications were made based on the author's preference😉.

# AUTHOR
Project was made with ❤ by [Eric Alaribe](https://github.com/smith2eric)